Dispatch
=====================
[![Travis branch](https://img.shields.io/travis/ubyssey/dispatch/develop.svg)](https://travis-ci.org/ubyssey/dispatch)
[![codecov](https://codecov.io/gh/ubyssey/dispatch/branch/develop/graph/badge.svg)](https://codecov.io/gh/ubyssey/dispatch)
[![PyPI](https://img.shields.io/pypi/v/dispatch.svg)](https://pypi.python.org/pypi/dispatch)

![dispatch](https://user-images.githubusercontent.com/9669739/46310500-679caf00-c574-11e8-9b70-d08f9bd03de3.png)

Dispatch is a publishing platform for modern newspapers and digital publications. Created in tandem by student journalists and developers, it aims to make online news more open, more hackable, and of course, more fun.

Made with :heart: by [_The Ubyssey_](https://www.ubyssey.ca/), the University of British Columbia's student newspaper since 1918.

## Installation

```
pip install dispatch
```

## Contribute

You can open issues for bugs you've found or features you think are missing. You can also submit pull requests to this repository. Follow the guide from [code.ubyssey.ca](https://code.ubyssey.ca/installation/dispatch-setup)

## License

GNU General Public License v2.0
